.. _api_reference:

API Reference
=============

:Release: |version|
:Date: |today|

.. module:: pydicom

This API reference guide details the functions, modules and objects included in
*pydicom*.

.. toctree::
   :maxdepth: 2
   :includehidden:

   charset
   config
   data
   datadict
   elem
   dataset
   handlers
   fileset
   dicomdir
   encaps
   errors
   fileio
   misc
   uid
